Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(99)

Unified Diff: net/ssl/ssl_cipher_suite_names.h

Issue 2395323002: Roll src/third_party/boringssl/src 0d81373f9..1991af690 (Closed)
Patch Set: rebase, roll further Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/socket/ssl_server_socket_unittest.cc ('k') | net/ssl/ssl_cipher_suite_names.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ssl/ssl_cipher_suite_names.h
diff --git a/net/ssl/ssl_cipher_suite_names.h b/net/ssl/ssl_cipher_suite_names.h
index 7c1192b279b2ec10d8d7820573c3a97c102d4950..36a6d152bb3fab49a70b94526137a2eea501e445 100644
--- a/net/ssl/ssl_cipher_suite_names.h
+++ b/net/ssl/ssl_cipher_suite_names.h
@@ -19,11 +19,15 @@ namespace net {
// wire and recorded at
// http://www.iana.org/assignments/tls-parameters/tls-parameters.xml
// If the cipher suite is unknown, the strings are set to "???".
// In the case of an AEAD cipher suite, *mac_str is NULL and *is_aead is true.
NET_EXPORT void SSLCipherSuiteToStrings(const char** key_exchange_str,
const char** cipher_str,
const char** mac_str,
bool* is_aead,
+ bool* is_tls13,
uint16_t cipher_suite);
// SSLVersionToString returns the name of the SSL protocol version
« no previous file with comments | « net/socket/ssl_server_socket_unittest.cc ('k') | net/ssl/ssl_cipher_suite_names.cc » ('j') | no next file with comments »
@@ -19,11 +19,15 @@ namespace net {
// http://www.iana.org/assignments/tls-parameters/tls-parameters.xml
// If the cipher suite is unknown, the strings are set to "???".
-// In the case of an AEAD cipher suite, *mac_str is NULL and *is_aead is true.
+// In the case of an AEAD cipher suite, *mac_str is nullptr and *is_aead is
+// true.
+// In the case of a TLS 1.3 AEAD-only cipher suite, *key_exchange_str is nullptr
+// and *is_tls13 is true.
NET_EXPORT void SSLCipherSuiteToStrings(const char** key_exchange_str,
const char** cipher_str,

Powered by Google App Engine
This is Rietveld 408576698